@@ -124,7 +124,11 @@ def to_snake_case(string):
         "extranetDTO": "extranet_dto",
         "locationGroupDTO": "location_group_dto",
         "locationDTO": "location_dto",
-        "predefinedADPControls": "predefined_adp_controls"
+        "predefinedADPControls": "predefined_adp_controls",
+        "runtimeOS": "runtime_os",
+        
+        # ZIdentity Edge Cases
+        # "clientJWKsUrl": "clientJWKsUrl",
     }
 
     if string in FIELD_EXCEPTIONS:
@@ -256,7 +260,8 @@ def to_lower_camel_case(string):
         "extranet_dto": "extranetDTO",
         "location_group_dto": "locationGroupDTO",
         "location_dto": "locationDTO",
-        "predefined_adp_controls": "predefinedADPControls"
+        "predefined_adp_controls": "predefinedADPControls",
+        "runtime_os": "runtimeOS"
     }
 
     if string in FIELD_EXCEPTIONS:
@@ -296,7 +301,14 @@ def convert_keys_to_camel_case(data):
     Handles nested lists and dictionaries.
     """
     if isinstance(data, dict):
-        return {to_lower_camel_case(k): convert_keys_to_camel_case(v) for k, v in data.items()}
+        result = {}
+        for k, v in data.items():
+            # Special handling for featurePermissions - preserve keys as-is
+            if k == "featurePermissions" and isinstance(v, dict):
+                result[k] = v  # Don't convert the keys inside featurePermissions
+            else:
+                result[to_lower_camel_case(k)] = convert_keys_to_camel_case(v)
+        return result
     elif isinstance(data, list):
         return [convert_keys_to_camel_case(item) for item in data]
     else:
