@@ -15,6 +15,7 @@ from zscaler.zdx.zdx_service import ZDXService
 from zscaler.zia.zia_service import ZIAService
 from zscaler.zpa.zpa_service import ZPAService
 from zscaler.zwa.zwa_service import ZWAService
+from zscaler.zidentity.zidentity_service import ZIdentityService
 from zscaler.zcc.legacy import LegacyZCCClientHelper
 from zscaler.ztw.legacy import LegacyZTWClientHelper
 from zscaler.zdx.legacy import LegacyZDXClientHelper
@@ -187,6 +188,7 @@ class Client:
         self._zwa = None
         self._zpa = None
         self._zdx = None
+        self._zidentity = None
         # self.logger.debug("Client initialized successfully.")
 
     def authenticate(self):
@@ -252,6 +254,12 @@ class Client:
             self._zpa = ZPAService(self._request_executor, self._config)
         return self._zpa
 
+    @property
+    def zidentity(self):
+        if self._zidentity is None:
+            self._zidentity = ZIdentityService(self._request_executor)
+        return self._zidentity
+    
     def __enter__(self):
         """
         Automatically create and set session within context manager.
@@ -268,6 +276,26 @@ class Client:
         if hasattr(self, "_session"):
             self._session.close()
             self.logger.debug("Session closed.")
+        
+        # Clean up Zscaler authentication session
+        if hasattr(self, '_request_executor'):
+            # For legacy clients, use their deauthenticate method
+            if self.use_legacy_client and hasattr(self._request_executor, 'deauthenticate'):
+                self.logger.debug("Deauthenticating Zscaler session via legacy client.")
+                self._request_executor.deauthenticate()
+                self.logger.debug("Zscaler session deauthenticated.")
+            # For OneAPI clients, use the request executor's deauthenticate method for ZIA/ZTW
+            elif not self.use_legacy_client and hasattr(self._request_executor, 'deauthenticate'):
+                # Get the service type from the request executor's last known service type
+                # or fall back to config if no requests were made
+                service_type = getattr(self._request_executor, '_last_service_type', None)
+                if not service_type:
+                    service_type = self._config.get("client", {}).get("service", "zia")
+                
+                if service_type.lower() in ["zia", "ztw"]:
+                    self.logger.debug(f"Deauthenticating Zscaler session for {service_type} service.")
+                    self._request_executor.deauthenticate(service_type)
+                    self.logger.debug(f"Zscaler session deauthenticated for {service_type}.")
 
     """
     Getters
