@@ -68,14 +68,25 @@ class ZscalerAPIResponse:
             self._params["endTime"] = end_time
 
         # If service is ZPA and user did not specify a pagesize, set it to max=500 by default
-        if self._service_type == "ZPA" and "pagesize" not in self._params:
+        if self._service_type.upper() == "ZPA" and "pagesize" not in self._params:
             self._params["pagesize"] = self.SERVICE_PAGE_LIMITS["ZPA"]["max"]
 
         # If service is ZIA, ensure the pagination parameter is "pageSize" in camelCase
-        if self._service_type == "ZIA":
+        if self._service_type == "zia":
             if "page_size" in self._params:
                 self._params["pageSize"] = self._params.pop("page_size")
 
+        if self._service_type == "zia":
+            # If user supplied pageNumber, initialize self._page accordingly
+            if "pageNumber" in self._params:
+                try:
+                    self._page = int(self._params["pageNumber"])
+                except Exception:
+                    self._page = 1
+            # Always remove 'page' if present for ZIA
+            self._params.pop("page", None)
+            # logger.debug(f"[DEBUG] __init__ params after ZIA normalization: {self._params}")
+
         if res_details:
             content_type = res_details.headers.get("Content-Type", "").lower()
 
@@ -149,6 +160,14 @@ class ZscalerAPIResponse:
         elif self._service_type == "ZDX":
             self._list = self._body.get("items", [])
             self._next_offset = self._body.get("next_offset")
+        elif self._service_type == "zidentity":
+            # Zidentity uses "records" field for paginated responses
+            self._list = self._body.get("records", [])
+            self._next_link = self._body.get("next_link")
+            self._prev_link = self._body.get("prev_link")
+            self._results_total = self._body.get("results_total")
+            self._page_offset = self._body.get("pageOffset")
+            self._page_size = self._body.get("pageSize")
         else:
             # ZPA and possibly other services use a dict with "list" field
             self._list = self._body.get("list", [])
@@ -211,14 +230,67 @@ class ZscalerAPIResponse:
         return results, self, None
 
 
+    # def _fetch_next_page(self):
+    #     if not self._has_next():
+    #         logger.debug("No more pages to fetch")
+    #         return [], None
+
+    #     if self._service_type == "ZDX":
+    #         self._params["offset"] = self._next_offset
+    #     else:
+    #         self._page += 1
+    #         self._params["page"] = self._page
+
+    #     logger.debug(f"Requesting next page with params: {self._params}")
+
+    #     req = {
+    #         "method": "GET",
+    #         "url": self._url,
+    #         "headers": self._headers,
+    #         "params": self._params,
+    #         "uuid": uuid.uuid4(),
+    #     }
+    #     _, _, response_body, error = self._request_executor.fire_request(req)
+
+    #     if error:
+    #         logger.error(f"Error fetching the next page: {error}")
+    #         return None, error
+
+    #     self._build_json_response(response_body)
+    #     return self._list, None
+
     def _fetch_next_page(self):
+        logger.debug(f"[DEBUG] _fetch_next_page called. service_type={self._service_type}, params={self._params}")
         if not self._has_next():
             logger.debug("No more pages to fetch")
             return [], None
 
-        if self._service_type == "ZDX":
+        if self._service_type.upper() == "ZDX":
+            logger.debug("[DEBUG] Taking ZDX pagination branch.")
             self._params["offset"] = self._next_offset
+        elif self._service_type.upper() == "ZIA":
+            logger.debug("[DEBUG] Taking ZIA pagination branch.")
+            self._page += 1
+            self._params["pageNumber"] = str(self._page)
+            # Ensure page parameter is never set for ZIA
+            self._params.pop("page", None)
+            logger.debug(f"[DEBUG] _fetch_next_page params for ZIA: {self._params}")
+        elif self._service_type == "zidentity":
+            logger.debug("[DEBUG] Taking ZIDENTITY pagination branch.")
+            # For Zidentity, use the next_link URL directly
+            if self._next_link:
+                # Parse the next_link URL to extract parameters
+                from urllib.parse import urlparse, parse_qs
+                parsed_url = urlparse(self._next_link)
+                query_params = parse_qs(parsed_url.query)
+                # Update params with the next page parameters
+                for key, value in query_params.items():
+                    self._params[key] = value[0] if len(value) == 1 else value
+                # Update the URL to the base URL (remove the full next_link)
+                self._url = f"{parsed_url.scheme}://{parsed_url.netloc}{parsed_url.path}"
+            logger.debug(f"[DEBUG] _fetch_next_page params for ZIDENTITY: {self._params}")
         else:
+            logger.debug("[DEBUG] Taking ZPA/other pagination branch.")
             self._page += 1
             self._params["page"] = self._page
 
@@ -252,6 +324,11 @@ class ZscalerAPIResponse:
             has_next = self._next_offset is not None
             logger.debug("Has next page for ZDX: %s", has_next)
             return has_next
+        elif self._service_type == "zidentity":
+            # More pages if next_link is not None
+            has_next = self._next_link is not None
+            logger.debug("Has next page for ZIDENTITY: %s", has_next)
+            return has_next
         else:
             # For ZIA/ZCC, if we got results last time, assume we can try next page
             # If next page returns empty, has_next() will be False on next call.
@@ -263,3 +340,9 @@ class ZscalerAPIResponse:
             # If the API doesn't give a clear signal that there's another page, we may need a heuristic.
             logger.debug("Has next page for ZIA/ZCC: %s", has_next)
             return has_next
+
+    def __str__(self):
+        try:
+            return json.dumps(self.get_results(), indent=2)
+        except Exception as e:
+            return f"<ZscalerAPIResponse error displaying results: {e}>"
\ No newline at end of file
