@@ -83,6 +83,7 @@ class RequestExecutor:
         self.service = self._config["client"].get("service", "zia")  # Default to ZIA
         self.customer_id = self._config["client"].get("customerId")  # Optional for ZIA/ZCC
         self.microtenant_id = self._config["client"].get("microtenantId")  # Optional for ZIA/ZCC
+        self.vanity_domain = self._config["client"].get("vanityDomain")  # Required for zidentity service
 
         # OAuth2 setup
         self._oauth = OAuth(self, self._config)
@@ -127,6 +128,18 @@ class RequestExecutor:
         # logger.debug(f"Determining base URL for cloud: {self.cloud}")
         if "/zscsb" in endpoint:
             return f"https://csbapi.{self.sandbox_cloud}.net"
+        
+        # Special handling for zidentity service
+        if "/zidentity" in endpoint or "/admin/api/v1" in endpoint:
+            if not self.vanity_domain:
+                raise ValueError("vanityDomain is required for zidentity service")
+            
+            # For zidentity, the URL pattern is: https://{{vanity_domain}}-admin.zslogin{{cloud}}.net/admin/api/v1
+            if self.cloud and self.cloud != "production":
+                return f"https://{self.vanity_domain}-admin.zslogin{self.cloud}.net/admin/api/v1"
+            else:
+                return f"https://{self.vanity_domain}-admin.zslogin.net/admin/api/v1"
+        
         if self.cloud and self.cloud != "production":
             return f"https://api.{self.cloud}.zsapi.net"
         return self.BASE_URL
@@ -147,7 +160,10 @@ class RequestExecutor:
             return "zwa"
         elif "/zpa" in url or "/mgmtconfig" in url:
             return "zpa"
-
+        elif "/admin/api/v1" in url:
+            return "zidentity"
+        elif "/admin" in url:
+            return "admin"
         if self.use_legacy_client:
             url = self.remove_oneapi_endpoint_prefix(url)
             # Recheck for service type after removing the prefix
@@ -163,11 +179,13 @@ class RequestExecutor:
                 return "zwa"
             elif "/zpa" in url or "/mgmtconfig" in url:
                 return "zpa"
+            elif "/admin/api/v1" in url:
+                return "zidentity"
 
         raise ValueError(f"Unsupported service: {url}")
 
     def remove_oneapi_endpoint_prefix(self, endpoint: str) -> str:
-        prefixes = ["/zia", "/zpa", "/zcc", "/ztw", "/zdx", "/zwa"]
+        prefixes = ["admin", "/zia", "/zpa", "/zcc", "/ztw", "/zdx", "/zwa"]
         for prefix in prefixes:
             if endpoint.startswith(prefix):
                 return endpoint[len(prefix) :]
@@ -188,7 +206,9 @@ class RequestExecutor:
             logger.error(f"Service detection failed: {e}")
             raise
 
-        body = body or {}
+        # Preserve empty lists, only convert None to empty dict
+        if body is None:
+            body = {}
         headers = headers or {}
         params = params or {}
 
@@ -212,6 +232,11 @@ class RequestExecutor:
         else:
             base_url = self.get_base_url(endpoint)
 
+        # Special handling for zidentity to avoid endpoint duplication
+        if service_type == "zidentity" and endpoint.startswith("/admin/api/v1/"):
+            # Remove the /admin/api/v1 prefix since it's already in the base URL
+            endpoint = endpoint[len("/admin/api/v1/"):]
+
         final_url = f"{base_url}/{endpoint.lstrip('/')}"
 
         headers = self._prepare_headers(headers, endpoint)
@@ -225,6 +250,9 @@ class RequestExecutor:
                 raise ValueError("Missing required sandboxToken in config.")
             params["api_token"] = sandbox_token
 
+        # Track the service type for deauthentication
+        self._last_service_type = service_type
+        
         request = {
             "method": method,
             "url": final_url,
@@ -254,6 +282,10 @@ class RequestExecutor:
         if self.use_legacy_client and self.zdx_legacy_client:
             return body  # Do not convert anything, just return as-is
 
+        # Special handling for ZDX endpoints - keep snake_case format
+        if "/zdx/" in endpoint:
+            return body  # Do not convert ZDX requests to camelCase
+
         # Preserve existing logic for other services
         if body:
             body = convert_keys_to_camel_case(body)
@@ -584,35 +616,80 @@ class RequestExecutor:
         logger.debug("Getting custom headers.")
         return self._custom_headers
 
-    # def get_retry_after(self, headers, logger):
-    #     retry_limit_reset_header = (
-    #         headers.get("x-ratelimit-reset") or 
-    #         headers.get("X-RateLimit-Reset") or
-    #         headers.get("RateLimit-Reset") or
+    def deauthenticate(self, service_type=None):
+        """
+        Deauthenticate from Zscaler services that support session-based authentication.
+        Currently supports ZIA and ZTW services.
+        
+        Args:
+            service_type (str, optional): The service type to deauthenticate from.
+                If None, will attempt to determine from the current configuration.
+        """
+        if not service_type:
+            service_type = self.service
+        
+        if service_type.lower() not in ["zia", "ztw"]:
+            logger.debug(f"Deauthentication not supported for service: {service_type}")
+            return False
+        
+        try:
+            # Determine the base URL and endpoint based on service type
+            if service_type.lower() == "zia":
+                if self.cloud and self.cloud != "production":
+                    base_url = f"https://api.{self.cloud}.zsapi.net"
+                else:
+                    base_url = "https://api.{self.cloud}.zsapi.net"
+                endpoint = "/zia/api/v1/authenticatedSession"
+            elif service_type.lower() == "ztw":
+                if self.cloud and self.cloud != "production":
+                    base_url = f"https://api.{self.cloud}.zsapi.net"
+                else:
+                    base_url = "https://api.{self.cloud}.zsapi.net"
+                endpoint = "/ztw/api/v1/auth"
             
-    #         # ZCC Specific Rate Limiting Headers (LegacyZCCClientHelper)
-    #         headers.get("X-Rate-Limit-Retry-After-Seconds") or # ZCC /downloadDevices Rate Limiting Header (LegacyZCCClientHelper)
-    #         headers.get("X-Rate-Limit-Remaining") # (LegacyZCCClientHelper)
-    #     )
-    #     retry_after = headers.get("Retry-After") or headers.get("retry-after")
+            url = f"{base_url}{endpoint}"
+            
+            # Prepare headers using the standard method to include bearer token
+            # For DELETE requests, we'll exclude Content-Type to avoid issues with empty body
+            headers = self._prepare_headers({}, endpoint)
+            # Remove Content-Type for DELETE requests to avoid issues with empty body
+            headers.pop("Content-Type", None)
+            
+            # Both ZIA and ZTW require explicit deauthentication to activate staged configurations
+            # regardless of authentication method (OAuth or session-based)
+            if service_type.lower() in ["zia", "ztw"]:
+                logger.debug(f"{service_type.upper()} service requires explicit deauthentication to activate staged configurations")
+            
+            # Send DELETE request to deauthenticate
+            logger.debug(f"Deauthenticating from {service_type} at {url}")
+            
+            # Use the HTTP client to send the request
+            request = {
+                "method": "DELETE",
+                "url": url,
+                "headers": headers,
+                "params": {},
+                "uuid": uuid.uuid4(),
+                "service_type": service_type,
+            }
+            
+            response, error = self._http_client.send_request(request)
+            
+            if error:
+                logger.warning(f"Failed to deauthenticate from {service_type}: {error}")
+                return False
+            
+            if response and response.status_code == 200:
+                logger.debug(f"Successfully deauthenticated from {service_type}")
+                return True
+            else:
+                logger.warning(f"Unexpected response during deauthentication: {response.status_code if response else 'No response'}")
+                return False
+                
+        except Exception as e:
+            logger.warning(f"Exception during deauthentication for {service_type}: {e}")
+            return False
 
-    #     if retry_after:
-    #         try:
-    #             return int(retry_after.strip("s")) + 1  # Add 1 second padding
-    #         except ValueError:
-    #             logger.error(f"Error parsing Retry-After header: {retry_after}")
-    #             return None
-
-    #     if retry_limit_reset_header is not None:
-    #         try:
-    #             reset_seconds = float(retry_limit_reset_header)
-    #             return reset_seconds + 1  # Add 1 second padding
-    #         except ValueError:
-    #             logger.error(f"Error parsing x-ratelimit-reset header: {retry_limit_reset_header}")
-    #             return None
-
-    #     logger.error("Missing Retry-After and X-Rate-Limit-Reset headers.")
-    #     return None
 
     def get_retry_after(self, headers, logger):
         retry_limit_reset_header = (
